"bassAckward" <- function(r,nfactors=1,fm="minres",rotate="oblimin",plot=TRUE,use="pairwise", cor="cor",weight=NULL,correct=.5,scores="regression") {
 cl <- match.call()
#find r if data matrix
    if (!isCorrelation(r)) {  matrix.input <- FALSE  #return the correlation matrix in this case
                       n.obs <- dim(r)[1]
     
   
    # if given a rectangular matrix, then find the correlation or covariance 
    #multiple ways of find correlations or covariances
    #added the weights option to tet, poly, tetrachoric, and polychoric  June 27, 2018
    switch(cor, 
       cor = {r <- cor(r,use=use)},
       cov = {r <- cov(r,use=use) 
              covar <- TRUE},
       wtd = { r <- cor.wt(r,w=weight)$r},
       tet = {r <- tetrachoric(r,correct=correct,weight=weight)$rho},
       poly = {r <- polychoric(r,correct=correct,weight=weight)$rho},
       tetrachoric = {r <- tetrachoric(r,correct=correct,weight=weight)$rho},
       polychoric = {r <- polychoric(r,correct=correct,weight=weight)$rho},
       mixed = {r <- mixed.cor(r,use=use,correct=correct)$rho},
       Yuleb = {r <- YuleCor(r,,bonett=TRUE)$rho},
       YuleQ = {r <- YuleCor(r,1)$rho},
       YuleY = {r <- YuleCor(r,.5)$rho } 
       )
       
  }

r.n <- list()
fa <- list()
if(fm =="pca") {
#do the conventional pca bass-akwards approach with components
pc <- pca(r)
pc.weights <- pc$weights
colnames(pc.weights) <- paste0("C",1)
for(nf in 1:nfactors) {
pcn <- pca(r,nf,rotate=rotate)
fa[[nf]] <- pcn$loadings
pcn.weights <- pcn$weights
colnames(pcn.weights) <- paste0("C",1:ncol(pcn.weights))
colnames(pc$weights) <- paste0("C",1:ncol(pc$weights))
r.n[[nf]] <-  t(pcn.weights) %*% r %*% pc$weights
pc <- pcn
}
} else { #factor analyze
f <- fa(r,fm=fm,rotate=rotate,scores=scores)
for(nf in 1:nfactors) {
fn <- fa(r,nf,rotate=rotate)
fa[[nf]] <- fn$loadings
fn.weights <- fn$weights
colnames(fn.weights) <- paste0("F",1:nf)
colnames(f$weights) <- paste0("F",1:ncol(f$weights))
r.n[[nf]] <-  t(fn.weights) %*% r %*% f$weights
f <- fn
}
}

#Now summarize the results 
sumlist <-  sumnames <- list()

for(f in 1:nf) {
sumlist[[f]] <- apply(r.n[[f]],2,function(x) {which(max(abs(x))==abs(x))})
sumnames[[f]] <- rownames(r.n[[f]])[sumlist[[f]]]
}

result <- list(Call=cl,fm=fm,bass.ack= r.n,summary=sumlist,sumnames=sumnames,fa=fa)
class(result) <- c("psych","bassAck")
if(plot) bassAckward.diagram(result)
return(result)
}

print.psych.back<- function(x,digits=2 ,short=TRUE) {

   cat("\nCall: ")
   print(x$Call)
nf <- length(x$bass.ack)
if(!short) {
for (f in 1:nf) {
print(round(x$bass.ack[[f]],digits=digits))}
}
for (f in 1:nf) {
cat("\n",f, 
x$sumnames[[f]])

}}


bassAckward.diagram <- function(x,digits=2,labels=NULL,marg=c(.5,.5,1.5,.5),
main="BassAckward",...) {
 old.par<- par(mar=marg)  #give the window some narrower margins
    on.exit(par(old.par))  #set them back
    
nf = length(x$bass.ack)
xlim <- c(0,nf)
ylim <- c(-1,(nf-1))
lower <- list()
upper <- list()
plot(0,type="n",xlim=xlim,ylim=ylim,frame.plot=FALSE,axes=FALSE,ylab="",xlab="",main=main)
#the bottom row
if(x$fm !="pca"){ for(j in 1:(nf)) {lower [[j] ] <- dia.rect(j,-1, paste0("F",j),...)} } else {
 for(j in 1:(nf)) {lower [[j] ] <- dia.rect(j,-1, paste0("C",j),...)} }

for(j in (nf):2) {
for(i in 1:(j-1)) {upper[[i]] <-  dia.rect(i,nf-j, labels=names(x$summary[[j]])[i],...) }
#connect them

for(i in 1:(j-1)) {
value <- x$bass.ack[j][[1]][x$summary[[j]][i],i]
dia.arrow(upper[[i]],lower[[x$summary[[j]][i] ]],labels = round(value,digits),...)
}
lower <- upper
}

}
