\name{bassAckward}
\alias{bassAckward}

\title{The Bass-Ackward factoring algorithm discussed by Goldberg.
}
\description{
Successive factor analyses from 1 to nf factors organized by factor correlations from  one level to the next.  The algorithm may be applied to principal components (pca) or to true factor analysis. Goldberg (2006) described a hierarchical factor structure organization from the ``top down".  Waller (2007) discussed a simple way of doing this for components. Here we have a function that uses factor correlations (from Gorsuch) to organize factors hierarchically.
}
\usage{
bassAckward(r, nfactors = 1, fm = "minres", rotate = "oblimin",plot=TRUE,
use = "pairwise",  cor = "cor", weight = NULL, correct = 0.5, scores = "regression")
}
\arguments{
  \item{r}{A correlation matrix or a data matrix suitable for factoring
}
  \item{nfactors}{Factors from 1 to nfactors will be extracted.
}
  \item{fm}{Factor method.  The default is 'minres' factoring.  Although to be consistent with the original Goldberg article, we can also do principal components (fm ="pca")
}
  \item{rotate}{What type of rotation to apply.  The default for factors is oblimin, for pca is varimax.}
  \item{plot}{By default draw a bassAckward diagram}
  \item{use}{How to treat missing data.  Use='pairwise" finds pairwise complete correlations.
}
  \item{cor}{What kind of correlation to find.  The default is Pearson.
}
  \item{weight}{Should cases be weighted?  Default, no.
}
  \item{correct}{If finding tetrachoric or polychoric correlations, what correction should be applied to empty cells (defaults to .5)
}
  \item{scores}{What factor scoring algorithm should be used.
}
}
\details{
This is just a wrapper to the \code{\link{fa}} and \code{\link{pca}} functions.  They are called repeatedly and then the weights from the resulting solutions are used to find the factor/component correlations. 

The function bassAckward.diagram may be called using the \code{\link{diagram}} function.
}
\value{
\item{Call}{Echo the call}
\item{fm}{Echos the factor method used}
item{fa}{A list of the factor loadings at each level}
\item{bass.ack}{A list of the factor correlations at each level}
\item{summary}{The factors at each level}
\item{sumnames}{Summary of the factor names}
}
\references{
Goldberg, L.R. (2006) Doing it all Bass-Ackwards: The development of hierarchical factor structures from the top down. Journal of Research in Personality, 40, 4, 347-358.

Gorsuch, Richard, (1983) Factor Analysis. Lawrence Erlebaum Associates.

Revelle, William. (in prep) An introduction to psychometric theory with applications in R. Springer.  Working draft available at \url{https://personality-project.org/r/book/} 


Waller, N. (2007), A general method for computing hierarchical component structures by Goldberg's Bass-Ackwards method, Journal of Research in Personality, 41, 4, 745-752,
 DOI: 10.1016/j.jrp.2006.08.005
}
\author{William Revelle}
\note{Goldberg calculated factor/component scores and then correlated these.  Waller suggests just looking at the unrotated components and then examining the correlations when rotating  different numbers of components.  I do not follow the Waller procedure, but rather find successive factors and then  find factor/component correlations following Gorsuch. 
}

\seealso{ \code{\link{fa}}, \code{\link{pca}},  \code{\link{omega}} and \code{\link{iclust}}  for alternative hierarchical solutions. 

}
\examples{
bassAckward(Thurstone,4)
bassAckward(bfi[1:25],7)
bassAckward(bfi[1:25],7,fm="pca") #do pca instead of factors

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{multivariate }
\keyword{ models}